# pyrois-common

This software is an implementation of HRI Engine on RoIS framework.
This software is released under the MIT License, see LICENSE.

## Overview

pyrois-common is an implementation of HRI Engine on RoIS framework with python3.
pyrois-common underlies pyrois, which is an implementation of RoIS framework.

## References

1. RoIS Framework
1. pyrois